%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%   Accounting for the Relative Importance of Objects in Image Retrieval
%   ( authored by Sung Ju Hwang and Kristen Grauman, BMVC 2010 )
%   
%   Implemented by T.W. Kim
%
%   This implementation experiments three approaches on image retrieval for verifying
%   the effect of relative importance of objects among images:
%                                        (visual-only / word + visual / semantic)
%
%
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%     INITIALIZATION
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% !!! MODIFY THE CODE ONE LINE BELOW with your directory path
root_path = '/storage/taewoo/BMVC2010/';
cd(root_path)
config = initialize();
clear root_path;

% load all the training data
[D taglist] = load_data(config, 'train');
disp('training data set are all loaded.');


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%     FEATURE EXTRACTION
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

F = extract_features(D, taglist, config);
disp('tag and visual features have been extracted.');


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%     TRAINING PHASE
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

K = create_kernel_matrices(F, config);
disp('kernel matrices have been calculated.');


% Kernelized Canonical Correlation Analysis (KCCA)
kapa.baseline = 13;
kapa.ours = 10;
eta = 0.5;
[baseline ours] = kcca(K, kapa, eta);
disp('KCCA has been done.');


% projection of training dataset onto the semantic space
S = semantic_projection(K, ours, baseline);
disp('semantic projection has been done.');



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%     TESTING PHASE
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

[TD test_taglist] = load_data(config, 'test');
TF = test_extract_features(TD, test_taglist, config);
TK = test_create_kernel_matrices(F, TF, K, config);

TS = semantic_projection(TK, ours, baseline);
R = retrieve(S, TS, TK, config);


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%     SHOWING RESULT
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


NDCG = evaluate(D, TD, R, config);
draw_ndcg(NDCG);
show_results(D, TD, R, config, 11, 20);

