function [max_kapa] = tune_parameter_kapa(F, D, K, config)

    k = 100;

    kapa_list = [ 0.1, 1, 10, 100, 1000 ];
    NDCG_list = zeros( numel(kapa_list), 2, k );
    
    eta = 0.5;
    for n = 1:length(kapa_list)

        kapa.baseline = kapa_list(n);
        kapa.ours = kapa_list(n);

        [baseline ours] = kcca(K, kapa, eta);
        S = semantic_projection(K, ours, baseline);
        
        TD = load_data(config, 'test');
        TF = test_extract_features(TD, [], config);
        TK = test_create_kernel_matrices(F, TF, K, config);
        TS = semantic_projection(TK, ours, baseline);
        R = retrieve(S, TS, TK, config);

        NDCG = evaluate(D, TD, R, config);

        NDCG_list(n, 1, :) = NDCG.word_visual(1:k);
        NDCG_list(n, 2, :) = NDCG.our_semantic(1:k);
    end





    data_baseline = [];
    for n=1:length(kapa_list)
        data_baseline(n, :) = reshape(NDCG_list(n, 1, :), [1, k]);
    end

    figure;
    hold on;
    for n=1:length(kapa_list)
        plot(data_baseline(n, :));
    end
    title('Kapa estimation : baseline');
    xlabel('Top k');
    ylabel('NDCG@K');
    legend('kapa=0.1', 'kapa=1', 'kapa=10', 'kapa=100', 'kapa=1000');
    hold off;




    data_ours = [];
    for n=1:length(kapa_list)
        data_ours(n, :) = reshape(NDCG_list(n, 2, :), [1, k]);
    end

    figure;
    hold on;
    for n=1:length(kapa_list)
        plot(data_ours(n, :));
    end
    title('Kapa estimation : Semantic model');
    xlabel('Top k');
    ylabel('NDCG@K');
    legend('kapa=0.1', 'kapa=1', 'kapa=10', 'kapa=100', 'kapa=1000');
    hold off;




end