function [max_kapa] = tune_parameter_kapa_2(F, D, K, config)

    % cross-validation
    trainDataSize = config.train.dataSize;
    trainIndex = 1:trainDataSize;
    valIndex = randsample(trainDataSize, floor(trainDataSize/10));
    trainIndex(valIndex) = [];

    Dtr = {};
    for n=1:length(trainIndex)
        Dtr(1, n).objectscale = D(1, trainIndex(n)).objectscale;
        Dtr(1, n).objectcount = D(1, trainIndex(n)).objectcount;
    end

    Dval = {};
    for n=1:length(valIndex)
        Dval(1, n).objectscale = D(1, valIndex(n)).objectscale;
        Dval(1, n).objectcount = D(1, valIndex(n)).objectcount; 
    end


    Ftr = {};
    Ftr.wc = F.wc(trainIndex, :);
    Ftr.rel = F.rel(trainIndex, :);
    Ftr.abs = F.abs(trainIndex, :);
    Ftr.gist = F.gist(trainIndex, :);
    Ftr.hsv = F.hsv(trainIndex, :);
    Ftr.bow = F.bow(trainIndex, :);

    Fval = {};
    Fval.wc = F.wc(valIndex, :);
    Fval.rel = F.rel(valIndex, :);
    Fval.abs = F.abs(valIndex, :);
    Fval.gist = F.gist(valIndex, :);
    Fval.hsv = F.hsv(valIndex, :);
    Fval.bow = F.bow(valIndex, :);

    Ktr = {};
    Ktr.wc = K.wc(trainIndex, trainIndex);
    Ktr.rel = K.rel(trainIndex, trainIndex);
    Ktr.abs = K.abs(trainIndex, trainIndex);
    Ktr.gist = K.gist(trainIndex, trainIndex);
    Ktr.hsv = K.hsv(trainIndex, trainIndex);
    Ktr.bow = K.bow(trainIndex, trainIndex);
    Ktr.wordrank = K.wordrank(trainIndex, trainIndex);
    Ktr.visual = K.visual(trainIndex, trainIndex);
    Ktr.wc_mean = K.wc_mean;
    Ktr.rel_mean = K.rel_mean;
    Ktr.abs_mean = K.abs_mean;
    Ktr.gist_mean = K.gist_mean;
    Ktr.hsv_mean = K.hsv_mean;
    Ktr.bow_mean = K.bow_mean;

    config.train.dataSize = trainDataSize - floor(trainDataSize/10);
    config.test.dataSize = floor(trainDataSize/10);
    config.test.numOfRetrieved = config.train.dataSize;



    % NDCG@K start
    k = 100;

    kapa_list = [ 6, 8, 10, 13 ];
    NDCG_list = zeros( numel(kapa_list), 2, k );
    
    eta = 0.5;
    for n = 1:length(kapa_list)
        tic

        kapa.baseline = kapa_list(n);
        kapa.ours = kapa_list(n);

        [baseline ours] = kcca(Ktr, kapa, eta);
        S = semantic_projection(Ktr, ours, baseline);

        TK = test_create_kernel_matrices(Ftr, Fval, K, config);
        TS = semantic_projection(TK, ours, baseline);
        R = retrieve(S, TS, TK, config);

        NDCG = evaluate(Dtr, Dval, R, config);

        NDCG_list(n, 1, :) = NDCG.word_visual(1:k);
        NDCG_list(n, 2, :) = NDCG.our_semantic(1:k);

        toc
    end





    data_baseline = [];
    for n=1:length(kapa_list)
        data_baseline(n, :) = reshape(NDCG_list(n, 1, :), [1, k]);
    end

    figure;
    hold on;
    for n=1:length(kapa_list)
        plot(data_baseline(n, :));
    end
    title('Kapa estimation : baseline');
    xlabel('Top k');
    ylabel('NDCG@K');
    legend('kapa=6', 'kapa=8', 'kapa=10', 'kapa=13');
    hold off;




    data_ours = [];
    for n=1:length(kapa_list)
        data_ours(n, :) = reshape(NDCG_list(n, 2, :), [1, k]);
    end

    figure;
    hold on;
    for n=1:length(kapa_list)
        plot(data_ours(n, :));
    end
    title('Kapa estimation : Semantic model');
    xlabel('Top k');
    ylabel('NDCG@K');
    legend('kapa=6', 'kapa=8', 'kapa=10', 'kapa=13');
    hold off;




end